@@ -403,7 +403,7 @@ proc ::tomsColorPaletteLib::palette_enter {dropwin tym} {
       }
     } else {
       if [string length $palette_info(dropcmd,$dropwin)]!=0 {
-	$palette_info(dropcmd,$dropwin) $palette_info(dragcolor)
+	eval $palette_info(dropcmd,$dropwin) $palette_info(dragcolor)
       }
       if [info exists palette_info(ispot,$dropwin)] {
 	$dropwin config -bg $palette_info(dragcolor)
@@ -461,7 +461,7 @@ proc ::tomsColorPaletteLib::palette_click {} {
   } else {
     set color [getPaletteCurrent]
     if [string length $palette_info(dropcmd,$palette_info(dragfrom))]!=0 {
-      $palette_info(dropcmd,$palette_info(dragfrom)) $color
+      eval $palette_info(dropcmd,$palette_info(dragfrom)) $color
     }
     if [info exists palette_info(ispot,$palette_info(dragfrom))] {
       $palette_info(dragfrom) config -bg $color
